# QA Launchpad Bug Reports
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Import json searches into django.  This may be replaced later."""

import json

from django.core.management.base import BaseCommand

from qlbr.models import Criterion, Item, Search, SearchTag, Project


class Command(BaseCommand):

    """Import json searches into django."""

    def handle(self, *args, **options):
        """Import json searches into django."""
        for filename in args:
            data = json.load(open(filename))
            for search in data:
                d_search = Search(name=search['name'])
                d_search.save()
                for tag in search['search_tags']:
                    d_tag = SearchTag(search_tag=tag)
                    d_tag.save()
                    d_search.search_tags.add(d_tag)
                for project in search['projects']:
                    d_project = Project(project=project)
                    d_project.save()
                    d_search.projects.add(d_project)
                for key in search['criteria']:
                    value = search['criteria'][key]
                    if isinstance(value, list):
                        d_criterion = Criterion(key=key, is_list=True)
                        d_criterion.save()
                        for item in value:
                            d_item = Item(item=item)
                            d_item.save()
                            d_criterion.values.add(d_item)
                    else:
                        d_criterion = Criterion(key=key, value=value)
                    d_criterion.save()
                    d_search.criteria.add(d_criterion)
                d_search.save()
