# QA Launchpad Bug Reports
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Provide team to project mappings."""

__all__ = [
    'TEAM_MAPPING',
    'PROJECT_MAPPING',
    'PROJECT_LIST',
    'PROJECT_CONFLICTS',
]

TEAM_MAPPING = {
    'Unity APIs': (
        'indicatordateandtime',
        'indicatorlocation',
        'messagingmenu',
        'networkmenu',
        'thesoundmenu',
        'thumbnailer',
        'transferindicator',
        'indicatortransfer',
        'urldispatcher',
        'unitymediascannerscope',
        'indicatorpower',
        'locationservice',
        'mediascanner',
        'mediascanner2',
        'payservice',
        'unityscopesapi',
        'unityscopesshell',
        'indicatornetwork',
        'unityscopeclick',
    ),
    'Phonedations': (
        'mediahub',
        'pulseaudio',
        'android',
        'bluez',
        'mtp',
        'networkmanager',
        'nuntium',
        'ofono',
        'platformapi',
        'powerd',
        'qtcreatorpluginubuntu',
        'qtubuntucamera',
        'qtubuntumedia',
    ),
    'Shell/Mir': (
        'mir',
        'qtmir',
        'unity8',
        'unitysystemcompositor',
        'qtubuntu',
        'ubuntutouchsession',
        'unitymir',
    ),
    'Apps': (
        'oempriorityproject',
        'addressbookapp',
        'cameraapp',
        'dialerapp',
        'galleryapp',
        'mediaplayerapp',
        'messagingapp',
        'notesapp',
        'syncmonitor',
        'telepathyofono',
        'telephonyservice',
        'ubuntukeyboard',
        'webbrowserapp',
    ),
    'Webapps/OA': (
        'onlineaccountssetupforubuntutouch',
        'onlineaccounts:accountplugins',
        'onlineaccounts:signonui',
        'thewebappscoreproject',
        'signon',
        'unitywebappsqml',
        'ubuntusystemsettingsonlineaccounts',
    ),
    'Security': (
        'oxide',
        'apparmor',
        'apparmoreasyprofubuntu',
        'oxideqt',
    ),
    'Community': (
        'sudokuapp',
        'ubuntuappdevelopersite',
        'ubuntufilemanagerapp',
        'ubuntumusicapp',
        'ubunturssfeedreaderapp',
        'ubuntuterminalapp',
        'ubuntutranslations',
        'ubuntuweatherapp',
    ),
    'SDK': (
        'ubuntuuitoolkit',
    ),
    'Design': (
        'ubuntuux',
    ),
    'Foundations': (
        'click',
        'livecdrootfs',
    ),
    'SystemSettings': (
        'ubuntusystemsettings',
    ),
    'Desktop': (
        'ubuntuonecredentials',
    ),
    'OnlineServices': (
    ),
    'Barajas': (
        'barajas',
        'thebarajasproject',
    )
}

PROJECT_MAPPING = {}
for team in TEAM_MAPPING:
    for target in TEAM_MAPPING[team]:
        PROJECT_MAPPING[target] = team

PROJECT_LIST = [target for target in PROJECT_MAPPING]

PROJECT_CONFLICTS = {}
for target in PROJECT_LIST:
    for target2 in PROJECT_LIST:
        if target in target2 and target is not target2:
            if target in PROJECT_CONFLICTS:
                PROJECT_CONFLICTS[target].append(target2)
            else:
                PROJECT_CONFLICTS[target] = [target2]
